pub enum ElectionState {
Candidate,
Leader,
Follower(Uuid),
}Expand description
The current role of a node in the Raft protocol.
Variants
Candidate
The node is campaigning for leadership.
Leader
The node is the current cluster leader and accepts writes.
Follower(Uuid)
The node is a follower of the leader identified by the inner Uuid.
A Uuid::nil() means no leader has been elected yet.